{% raw %}
{% load mote_tags %}
{% mask element.json.data.Language_list_centered as "language_centered" %}
<div class="languages">
  <ul class="language-list language-list--standard-center">
    {% for item in language_centered.languages %}
        <li class="language-list__item language-list__item--standard-center">{{ item.language }}</li>
    {% endfor %}
  </ul>
</div>
{% endraw %}
