{% raw %}
{% load mote_tags %}
<div class="pagination">
  <a href="#" class="pagination__nav-anchor-previous">&larr;</a>
    <span class="pagination__current-page">
      Page 1 of 2
    </span>
  <a href="#" class="pagination__nav-anchor-next">&rarr;</a>
</div>
{% endraw %}
