{% raw %}
{% load mote_tags %}
{% mask element.json.data.Language_list_with_label as "language_label" %}
<div class="languages">
  <ul class="language-list language-list--with-label">
    <li class="language-list__item language-list__item--with-label">
      <span class="language-list--with-label__title">Language</span>
    </li>
    {% for item in language_label.languages %}
        <li class="language-list__item language-list__item--with-label">{{ item.language }}</li>
    {% endfor %}
  </ul>
</div>
{% endraw %}
