{% raw %}
{% load mote_tags %}
<div class="teaser-meta-list">
  <div class="teaser-meta-list__comment-counter">
    <span class="teaser-meta-list__comment-label">comments</span>12
  </div>
  <div class="article-teaser-list__reply-counter">
    4 <span class="article-teaser-list__reply-label">replies</span>
  </div>
</div>
{% endraw %}
