{% raw %}
{% load mote_tags %}
<div class="copyright">
  <p class="copyright__footer-copy">
    &copy;  <span class="copyright__website-name">Website name</span>All Rights Reserved.
  </p>
</div>
{% endraw %}
