{% load i18n %}
<div id="gem-footer">
  {% trans "Search" as placeholdertext %}
  {% include "patterns/basics/search/sp_variations/search-button-icon.html" with radius="none" placeholder=placeholdertext %}
  {% include "patterns/basics/menu/sp_variations/menu-column.html" %}
</div>
