.menu-list {
    &--profile-icon {
      text-align: left;
      display: block;
      #profile_register {
        margin: -8px 0 0 0;
      }
    }
    &__item {
        &--profile-icon {
          &:after {
            content: "|";
            font-size: 20px;
            vertical-align: middle;
          }
          &:last-child {
            &:after {
              display: none;
            }
          }
        }
    }
    &__anchor {
        &--profile-icon {
          vertical-align: middle;
          font-size: 16px;
        }
    }
}
