{% load wagtailcore_tags core_tags  %}
<h2 class="heading heading-section-article heading-section-article{{hintstyle}}">
  <a href="{% pageurl section %}" class="heading-section-article__link">{{section.title}}</a>
</h2>
