{% load i18n %}
<div class="call-to-action call-to-action--backToTop">
  <a id="back-to-top" href="#" class="call-to-action__nav-item-text call-to-action__nav-item-text--backToTop">
    {% trans "Back to Top" %}
  </a>
</div>
