{% load wagtailcore_tags i18n %}
<div class="call-to-action call-to-action--wide-back">
  <a href="{% url 'tags_list' tag.slug %}" class="call-to-action__nav-item-text call-to-action__nav-item-text--{{direction}}">
    {% trans "Back" %} {{ tag }}
  </a>
</div>
