<div class="section-listing section-listing_theme-headings section-listing_theme-headings{{self.get_effective_extra_style_hints}}">
  {% include "patterns/basics/sections/sectionpage-subsection-list-headings.html" %}
  {% include "patterns/basics/sections/sectionpage-article-list-headings.html" %}
</div>
