/*
CORE STYLE OVERIDES
WAGTAIL ADMIN
*/
@import "../utilities/*";
@import "modules/*";

.wrapper {
  width: 100%;
}
.content-wrapper {
  .pagination {padding: 0 15px;}
  .pagination.col9 {
    width: 100%;
    p {padding: 15px 0 0;}
    ul {padding: 0 45px;}
  }
}
//COMMENT TABLE CONTENT
.submit-row .button {
  margin: 0 0 8px 0;
}
@media screen and (min-width: 50em) {
  .nav-wrapper {
    min-width: 12.6%;
    max-width: 180px;
    .inner {
      min-width: 12.6%;
      max-width: 180px;
    }
  }
  .content-wrapper {
    .pagination {
      padding: 0;
    }
  }
}
@media screen and (min-width: 90em) {
  body.login.ready .wrapper {
    padding-left: 100px !important;
  }
  body.ready .wrapper {
    padding-left: 12.8% !important;
  }
  .wrapper {
    max-width: 100%;
  }
}
